@@ -4,16 +4,20 @@
 package main
 
 import (
+	"context"
 	"maps"
 	"os"
 
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 
-	"github.com/lima-vm/lima/pkg/downloader"
-	"github.com/lima-vm/lima/pkg/limayaml"
-	"github.com/lima-vm/lima/pkg/store"
-	"github.com/lima-vm/lima/pkg/templatestore"
+	"github.com/lima-vm/lima/v2/pkg/downloader"
+	"github.com/lima-vm/lima/v2/pkg/driverutil"
+	"github.com/lima-vm/lima/v2/pkg/limatmpl"
+	"github.com/lima-vm/lima/v2/pkg/limatype"
+	"github.com/lima-vm/lima/v2/pkg/limayaml"
+	"github.com/lima-vm/lima/v2/pkg/store"
+	"github.com/lima-vm/lima/v2/pkg/templatestore"
 )
 
 func newPruneCommand() *cobra.Command {
@@ -30,6 +34,7 @@ func newPruneCommand() *cobra.Command {
 }
 
 func pruneAction(cmd *cobra.Command, _ []string) error {
+	ctx := cmd.Context()
 	keepReferred, err := cmd.Flags().GetBool("keep-referred")
 	if err != nil {
 		return err
@@ -44,7 +49,7 @@ func pruneAction(cmd *cobra.Command, _ []string) error {
 	if err != nil {
 		return err
 	}
-	knownLocations, err := knownLocations()
+	knownLocations, err := knownLocations(ctx)
 	if err != nil {
 		return err
 	}
@@ -62,8 +67,8 @@ func pruneAction(cmd *cobra.Command, _ []string) error {
 	return nil
 }
 
-func knownLocations() (map[string]limayaml.File, error) {
-	locations := make(map[string]limayaml.File)
+func knownLocations(ctx context.Context) (map[string]limatype.File, error) {
+	locations := make(map[string]limatype.File)
 
 	// Collect locations from instances
 	instances, err := store.Instances()
@@ -71,10 +76,14 @@ func knownLocations() (map[string]limayaml.File, error) {
 		return nil, err
 	}
 	for _, instanceName := range instances {
-		instance, err := store.Inspect(instanceName)
+		instance, err := store.Inspect(ctx, instanceName)
 		if err != nil {
 			return nil, err
 		}
+		if instance.Errors != nil {
+			logrus.Warnf("skipping instance %q because it has errors: %v", instanceName, instance.Errors)
+			continue
+		}
 		maps.Copy(locations, locationsFromLimaYAML(instance.Config))
 	}
 
@@ -84,21 +93,27 @@ func knownLocations() (map[string]limayaml.File, error) {
 		return nil, err
 	}
 	for _, t := range templates {
-		b, err := templatestore.Read(t.Name)
+		tmpl, err := limatmpl.Read(ctx, "", t.Location)
 		if err != nil {
 			return nil, err
 		}
-		y, err := limayaml.Load(b, t.Name)
+		if err := tmpl.Embed(ctx, true, true); err != nil {
+			return nil, err
+		}
+		y, err := limayaml.Load(ctx, tmpl.Bytes, tmpl.Name)
 		if err != nil {
 			return nil, err
 		}
+		if err := driverutil.ResolveVMType(ctx, y, t.Name); err != nil {
+			logrus.Warnf("failed to resolve vmType for %q: %v", t.Name, err)
+		}
 		maps.Copy(locations, locationsFromLimaYAML(y))
 	}
 	return locations, nil
 }
 
-func locationsFromLimaYAML(y *limayaml.LimaYAML) map[string]limayaml.File {
-	locations := make(map[string]limayaml.File)
+func locationsFromLimaYAML(y *limatype.LimaYAML) map[string]limatype.File {
+	locations := make(map[string]limatype.File)
 	for _, f := range y.Images {
 		locations[downloader.CacheKey(f.Location)] = f.File
 		if f.Kernel != nil {
