@@ -10,7 +10,7 @@ import (
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 
-	"github.com/lima-vm/lima/pkg/store"
+	"github.com/lima-vm/lima/v2/pkg/store"
 )
 
 func newUnprotectCommand() *cobra.Command {
@@ -25,10 +25,11 @@ func newUnprotectCommand() *cobra.Command {
 	return unprotectCommand
 }
 
-func unprotectAction(_ *cobra.Command, args []string) error {
+func unprotectAction(cmd *cobra.Command, args []string) error {
+	ctx := cmd.Context()
 	var errs []error
 	for _, instName := range args {
-		inst, err := store.Inspect(instName)
+		inst, err := store.Inspect(ctx, instName)
 		if err != nil {
 			errs = append(errs, fmt.Errorf("failed to inspect instance %q: %w", instName, err))
 			continue
