@@ -11,15 +11,16 @@ import (
 	"path/filepath"
 
 	"github.com/docker/go-units"
+	"github.com/lima-vm/go-qcow2reader/image"
 
 	"github.com/lima-vm/lima/v2/pkg/imgutil/proxyimgutil"
 	"github.com/lima-vm/lima/v2/pkg/iso9660util"
-	"github.com/lima-vm/lima/v2/pkg/limatype"
 	"github.com/lima-vm/lima/v2/pkg/limatype/filenames"
 )
 
-func EnsureDiskRaw(ctx context.Context, inst *limatype.Instance) error {
-	diffDisk := filepath.Join(inst.Dir, filenames.DiffDisk)
+// EnsureDisk ensures that the diff disk exists with the specified size and format.
+func EnsureDisk(ctx context.Context, instDir, diskSize string, diskImageFormat image.Type) error {
+	diffDisk := filepath.Join(instDir, filenames.DiffDisk)
 	if _, err := os.Stat(diffDisk); err == nil || !errors.Is(err, os.ErrNotExist) {
 		// disk is already ensured
 		return err
@@ -27,32 +28,34 @@ func EnsureDiskRaw(ctx context.Context, inst *limatype.Instance) error {
 
 	diskUtil := proxyimgutil.NewDiskUtil(ctx)
 
-	baseDisk := filepath.Join(inst.Dir, filenames.BaseDisk)
+	baseDisk := filepath.Join(instDir, filenames.BaseDisk)
 
-	diskSize, _ := units.RAMInBytes(*inst.Config.Disk)
-	if diskSize == 0 {
+	diskSizeInBytes, _ := units.RAMInBytes(diskSize)
+	if diskSizeInBytes == 0 {
 		return nil
 	}
 	isBaseDiskISO, err := iso9660util.IsISO9660(baseDisk)
 	if err != nil {
 		return err
 	}
+	srcDisk := baseDisk
 	if isBaseDiskISO {
-		// Create an empty data volume (sparse)
+		srcDisk = diffDisk
+
+		// Create an empty data volume for the diff disk
 		diffDiskF, err := os.Create(diffDisk)
 		if err != nil {
 			return err
 		}
 
-		err = diskUtil.MakeSparse(ctx, diffDiskF, 0)
-		if err != nil {
-			diffDiskF.Close()
-			return fmt.Errorf("failed to create sparse diff disk %q: %w", diffDisk, err)
+		if err = diffDiskF.Close(); err != nil {
+			return err
 		}
-		return diffDiskF.Close()
 	}
-	if err = diskUtil.ConvertToRaw(ctx, baseDisk, diffDisk, &diskSize, false); err != nil {
-		return fmt.Errorf("failed to convert %q to a raw disk %q: %w", baseDisk, diffDisk, err)
+	// Check whether to use ASIF format
+
+	if err = diskUtil.Convert(ctx, diskImageFormat, srcDisk, diffDisk, &diskSizeInBytes, false); err != nil {
+		return fmt.Errorf("failed to convert %q to a disk %q: %w", srcDisk, diffDisk, err)
 	}
 	return err
 }
