@@ -500,7 +500,7 @@ func (a *HostAgent) startHostAgentRoutines(ctx context.Context) error {
 		msg := "Running in plain mode. Mounts, dynamic port forwarding, containerd, etc. will be ignored. Guest agent will not be running."
 		for _, port := range a.instConfig.PortForwards {
 			if port.Static {
-				msg += " Static port forwarding is allowed."
+				msg += " Static port forwarding is allowed." //nolint:modernize // stringsbuilder is not needed
 				break
 			}
 		}
@@ -1063,8 +1063,7 @@ func (a *HostAgent) watchCloudInitProgress(ctx context.Context) {
 
 		finalCmd := exec.CommandContext(ctx, a.sshConfig.Binary(), finalArgs...)
 		if finalOutput, err := finalCmd.Output(); err == nil {
-			lines := strings.Split(string(finalOutput), "\n")
-			for _, line := range lines {
+			for line := range strings.SplitSeq(string(finalOutput), "\n") {
 				if strings.TrimSpace(line) != "" {
 					if !cloudInitFinished {
 						cloudInitFinished = isCloudInitFinished(line)
