@@ -11,6 +11,6 @@ import (
 	"github.com/lima-vm/sshocker/pkg/ssh"
 )
 
-func forwardTCP(ctx context.Context, sshConfig *ssh.SSHConfig, port int, local, remote, verb string) error {
-	return forwardSSH(ctx, sshConfig, port, local, remote, verb, false)
+func forwardTCP(ctx context.Context, sshConfig *ssh.SSHConfig, sshAddress string, sshPort int, local, remote, verb string) error {
+	return forwardSSH(ctx, sshConfig, sshAddress, sshPort, local, remote, verb, false)
 }
