@@ -6,6 +6,8 @@ package imgutil
 import (
 	"context"
 	"os"
+
+	"github.com/lima-vm/go-qcow2reader/image"
 )
 
 // ImageDiskManager defines the common operations for disk image utilities.
@@ -16,8 +18,8 @@ type ImageDiskManager interface {
 	// ResizeDisk resizes an existing disk image to the specified size.
 	ResizeDisk(ctx context.Context, disk string, size int64) error
 
-	// ConvertToRaw converts a disk image to raw format.
-	ConvertToRaw(ctx context.Context, source, dest string, size *int64, allowSourceWithBackingFile bool) error
+	// Convert converts a disk image to the specified format.
+	Convert(ctx context.Context, imageType image.Type, source, dest string, size *int64, allowSourceWithBackingFile bool) error
 
 	// MakeSparse makes a file sparse, starting from the specified offset.
 	MakeSparse(ctx context.Context, f *os.File, offset int64) error
