@@ -11,6 +11,7 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/lima-vm/go-qcow2reader/image/raw"
 	"gotest.tools/v3/assert"
 )
 
@@ -65,7 +66,7 @@ func TestConvertToRaw(t *testing.T) {
 	t.Run("qcow without backing file", func(t *testing.T) {
 		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"), "/", "_"))
 
-		err = convertToRaw(qcowImage.Name(), resultImage, nil, false)
+		err = convertTo(raw.Type, qcowImage.Name(), resultImage, nil, false)
 		assert.NilError(t, err)
 		assertFileEquals(t, rawImage.Name(), resultImage)
 	})
@@ -73,7 +74,7 @@ func TestConvertToRaw(t *testing.T) {
 	t.Run("qcow with backing file", func(t *testing.T) {
 		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"), "/", "_"))
 
-		err = convertToRaw(qcowImage.Name(), resultImage, nil, true)
+		err = convertTo(raw.Type, qcowImage.Name(), resultImage, nil, true)
 		assert.NilError(t, err)
 		assertFileEquals(t, rawImage.Name(), resultImage)
 	})
@@ -82,7 +83,7 @@ func TestConvertToRaw(t *testing.T) {
 		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"), "/", "_"))
 
 		size := int64(2_097_152) // 2mb
-		err = convertToRaw(qcowImage.Name(), resultImage, &size, false)
+		err = convertTo(raw.Type, qcowImage.Name(), resultImage, &size, false)
 		assert.NilError(t, err)
 		assertFileEquals(t, rawImageExtended.Name(), resultImage)
 	})
@@ -90,7 +91,7 @@ func TestConvertToRaw(t *testing.T) {
 	t.Run("raw", func(t *testing.T) {
 		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"), "/", "_"))
 
-		err = convertToRaw(rawImage.Name(), resultImage, nil, false)
+		err = convertTo(raw.Type, rawImage.Name(), resultImage, nil, false)
 		assert.NilError(t, err)
 		assertFileEquals(t, rawImage.Name(), resultImage)
 	})
