@@ -19,58 +19,25 @@ import (
 	"github.com/lima-vm/go-qcow2reader"
 	"github.com/sirupsen/logrus"
 
-	"github.com/lima-vm/lima/pkg/downloader"
-	"github.com/lima-vm/lima/pkg/driver"
-	"github.com/lima-vm/lima/pkg/driverutil"
-	"github.com/lima-vm/lima/pkg/executil"
-	"github.com/lima-vm/lima/pkg/fileutils"
-	hostagentevents "github.com/lima-vm/lima/pkg/hostagent/events"
-	"github.com/lima-vm/lima/pkg/imgutil/proxyimgutil"
-	"github.com/lima-vm/lima/pkg/limayaml"
-	"github.com/lima-vm/lima/pkg/store"
-	"github.com/lima-vm/lima/pkg/store/filenames"
-	"github.com/lima-vm/lima/pkg/usrlocalsharelima"
+	"github.com/lima-vm/lima/v2/pkg/autostart"
+	"github.com/lima-vm/lima/v2/pkg/cacheutil"
+	"github.com/lima-vm/lima/v2/pkg/driver"
+	"github.com/lima-vm/lima/v2/pkg/driverutil"
+	"github.com/lima-vm/lima/v2/pkg/executil"
+	"github.com/lima-vm/lima/v2/pkg/fileutils"
+	hostagentevents "github.com/lima-vm/lima/v2/pkg/hostagent/events"
+	"github.com/lima-vm/lima/v2/pkg/imgutil/proxyimgutil"
+	"github.com/lima-vm/lima/v2/pkg/limatype"
+	"github.com/lima-vm/lima/v2/pkg/limatype/filenames"
+	"github.com/lima-vm/lima/v2/pkg/registry"
+	"github.com/lima-vm/lima/v2/pkg/store"
+	"github.com/lima-vm/lima/v2/pkg/usrlocal"
 )
 
 // DefaultWatchHostAgentEventsTimeout is the duration to wait for the instance
 // to be running before timing out.
 const DefaultWatchHostAgentEventsTimeout = 10 * time.Minute
 
-// ensureNerdctlArchiveCache prefetches the nerdctl-full-VERSION-GOOS-GOARCH.tar.gz archive
-// into the cache before launching the hostagent process, so that we can show the progress in tty.
-// https://github.com/lima-vm/lima/issues/326
-func ensureNerdctlArchiveCache(ctx context.Context, y *limayaml.LimaYAML, created bool) (string, error) {
-	if !*y.Containerd.System && !*y.Containerd.User {
-		// nerdctl archive is not needed
-		return "", nil
-	}
-
-	errs := make([]error, len(y.Containerd.Archives))
-	for i, f := range y.Containerd.Archives {
-		// Skip downloading again if the file is already in the cache
-		if created && f.Arch == *y.Arch && !downloader.IsLocal(f.Location) {
-			path, err := fileutils.CachedFile(f)
-			if err == nil {
-				return path, nil
-			}
-		}
-		path, err := fileutils.DownloadFile(ctx, "", f, false, "the nerdctl archive", *y.Arch)
-		if err != nil {
-			errs[i] = err
-			continue
-		}
-		if path == "" {
-			if downloader.IsLocal(f.Location) {
-				return f.Location, nil
-			}
-			return "", fmt.Errorf("cache did not contain %q", f.Location)
-		}
-		return path, nil
-	}
-
-	return "", fileutils.Errors(errs)
-}
-
 type Prepared struct {
 	Driver              driver.Driver
 	GuestAgent          string
@@ -78,28 +45,30 @@ type Prepared struct {
 }
 
 // Prepare ensures the disk, the nerdctl archive, etc.
-func Prepare(ctx context.Context, inst *store.Instance) (*Prepared, error) {
-	var guestAgent string
-	if !*inst.Config.Plain {
+func Prepare(ctx context.Context, inst *limatype.Instance, guestAgent string) (*Prepared, error) {
+	if !*inst.Config.Plain && guestAgent == "" {
 		var err error
-		guestAgent, err = usrlocalsharelima.GuestAgentBinary(*inst.Config.OS, *inst.Config.Arch)
+		guestAgent, err = usrlocal.GuestAgentBinary(*inst.Config.OS, *inst.Config.Arch)
 		if err != nil {
 			return nil, err
 		}
 	}
-	limaDriver := driverutil.CreateTargetDriverInstance(inst, 0)
+	limaDriver, err := driverutil.CreateConfiguredDriver(inst, 0)
+	if err != nil {
+		return nil, fmt.Errorf("failed to create driver instance: %w", err)
+	}
 
-	if err := limaDriver.Validate(); err != nil {
+	if err := limaDriver.Validate(ctx); err != nil {
 		return nil, err
 	}
 
-	if err := limaDriver.Initialize(ctx); err != nil {
+	if err := limaDriver.Create(ctx); err != nil {
 		return nil, err
 	}
 
 	// Check if the instance has been created (the base disk already exists)
 	baseDisk := filepath.Join(inst.Dir, filenames.BaseDisk)
-	_, err := os.Stat(baseDisk)
+	_, err = os.Stat(baseDisk)
 	created := err == nil
 
 	kernel := filepath.Join(inst.Dir, filenames.Kernel)
@@ -146,11 +115,11 @@ func Prepare(ctx context.Context, inst *store.Instance) (*Prepared, error) {
 	}
 
 	// Ensure diffDisk size matches the store
-	if err := prepareDiffDisk(inst); err != nil {
+	if err := prepareDiffDisk(ctx, inst); err != nil {
 		return nil, err
 	}
 
-	nerdctlArchiveCache, err := ensureNerdctlArchiveCache(ctx, inst.Config, created)
+	nerdctlArchiveCache, err := cacheutil.EnsureNerdctlArchiveCache(ctx, inst.Config, created)
 	if err != nil {
 		return nil, err
 	}
@@ -162,29 +131,33 @@ func Prepare(ctx context.Context, inst *store.Instance) (*Prepared, error) {
 	}, nil
 }
 
-// Start starts the hostagent in the background, which in turn will start the instance.
-// Start will listen to hostagent events and log them to STDOUT until either the instance
+// StartWithPaths starts the hostagent in the background, which in turn will start the instance.
+// StartWithPaths will listen to hostagent events and log them to STDOUT until either the instance
 // is running, or has failed to start.
 //
-// The `limactl` argument allows the caller to specify the full path of the `limactl` executable.
-// When called from inside limactl itself it will always be the empty string which uses the name
-// of the current executable instead.
-//
-// The `launchHostAgentForeground` argument makes the hostagent run in the foreground.
+// The launchHostAgentForeground argument makes the hostagent run in the foreground.
 // The function will continue to listen and log hostagent events until the instance is
 // shut down again.
 //
-// Start calls Prepare by itself, so you do not need to call Prepare manually before calling Start.
-func Start(ctx context.Context, inst *store.Instance, limactl string, launchHostAgentForeground bool) error {
+// The showProgress argument tells the hostagent to show provision script progress by tailing cloud-init logs.
+//
+// The limactl argument allows the caller to specify the full path of the limactl executable.
+// The guestAgent argument allows the caller to specify the full path of the guest agent executable.
+// Inside limactl this function is only called by Start, which passes empty strings for both
+// limactl and guestAgent, in which case the location of the current executable is used for
+// limactl and the guest agent is located from the corresponding <prefix>/share/lima directory.
+//
+// StartWithPaths calls Prepare by itself, so you do not need to call Prepare manually before calling Start.
+func StartWithPaths(ctx context.Context, inst *limatype.Instance, launchHostAgentForeground, showProgress bool, limactl, guestAgent string) error {
 	haPIDPath := filepath.Join(inst.Dir, filenames.HostAgentPID)
 	if _, err := os.Stat(haPIDPath); !errors.Is(err, os.ErrNotExist) {
 		return fmt.Errorf("instance %q seems running (hint: remove %q if the instance is not actually running)", inst.Name, haPIDPath)
 	}
-	logrus.Infof("Starting the instance %q with VM driver %q", inst.Name, inst.VMType)
+	logrus.Infof("Starting the instance %q with %s VM driver %q", inst.Name, registry.CheckInternalOrExternal(inst.VMType), inst.VMType)
 
 	haSockPath := filepath.Join(inst.Dir, filenames.HostAgentSock)
 
-	prepared, err := Prepare(ctx, inst)
+	prepared, err := Prepare(ctx, inst, guestAgent)
 	if err != nil {
 		return err
 	}
@@ -197,60 +170,70 @@ func Start(ctx context.Context, inst *store.Instance, limactl string, launchHost
 	}
 	haStdoutPath := filepath.Join(inst.Dir, filenames.HostAgentStdoutLog)
 	haStderrPath := filepath.Join(inst.Dir, filenames.HostAgentStderrLog)
-	if err := os.RemoveAll(haStdoutPath); err != nil {
-		return err
-	}
-	if err := os.RemoveAll(haStderrPath); err != nil {
-		return err
-	}
-	haStdoutW, err := os.Create(haStdoutPath)
-	if err != nil {
-		return err
-	}
-	// no defer haStdoutW.Close()
-	haStderrW, err := os.Create(haStderrPath)
-	if err != nil {
-		return err
-	}
-	// no defer haStderrW.Close()
-
-	var args []string
-	if logrus.GetLevel() >= logrus.DebugLevel {
-		args = append(args, "--debug")
-	}
-	args = append(args,
-		"hostagent",
-		"--pidfile", haPIDPath,
-		"--socket", haSockPath)
-	if prepared.Driver.CanRunGUI() {
-		args = append(args, "--run-gui")
-	}
-	if prepared.GuestAgent != "" {
-		args = append(args, "--guestagent", prepared.GuestAgent)
-	}
-	if prepared.NerdctlArchiveCache != "" {
-		args = append(args, "--nerdctl-archive", prepared.NerdctlArchiveCache)
-	}
-	args = append(args, inst.Name)
-	haCmd := exec.CommandContext(ctx, limactl, args...)
-
-	if launchHostAgentForeground {
-		haCmd.SysProcAttr = executil.ForegroundSysProcAttr
-	} else {
-		haCmd.SysProcAttr = executil.BackgroundSysProcAttr
-	}
-
-	haCmd.Stdout = haStdoutW
-	haCmd.Stderr = haStderrW
 
 	begin := time.Now() // used for logrus propagation
-
-	if launchHostAgentForeground {
-		if err := execHostAgentForeground(limactl, haCmd); err != nil {
+	var haCmd *exec.Cmd
+	if isRegisteredToAutoStart, err := autostart.IsRegistered(ctx, inst); err != nil && !errors.Is(err, autostart.ErrNotSupported) {
+		return fmt.Errorf("failed to check autostart registration: %w", err)
+	} else if !isRegisteredToAutoStart || launchHostAgentForeground {
+		if err := os.RemoveAll(haStdoutPath); err != nil {
 			return err
 		}
-	} else if err := haCmd.Start(); err != nil {
-		return err
+		if err := os.RemoveAll(haStderrPath); err != nil {
+			return err
+		}
+		haStdoutW, err := os.Create(haStdoutPath)
+		if err != nil {
+			return err
+		}
+		// no defer haStdoutW.Close()
+		haStderrW, err := os.Create(haStderrPath)
+		if err != nil {
+			return err
+		}
+		// no defer haStderrW.Close()
+
+		var args []string
+		if logrus.GetLevel() >= logrus.DebugLevel {
+			args = append(args, "--debug")
+		}
+		args = append(args,
+			"hostagent",
+			"--pidfile", haPIDPath,
+			"--socket", haSockPath)
+		if prepared.Driver.Info().Features.CanRunGUI {
+			args = append(args, "--run-gui")
+		}
+		if prepared.GuestAgent != "" {
+			args = append(args, "--guestagent", prepared.GuestAgent)
+		}
+		if prepared.NerdctlArchiveCache != "" {
+			args = append(args, "--nerdctl-archive", prepared.NerdctlArchiveCache)
+		}
+		if showProgress {
+			args = append(args, "--progress")
+		}
+		args = append(args, inst.Name)
+		haCmd = exec.CommandContext(ctx, limactl, args...)
+
+		haCmd.SysProcAttr = executil.BackgroundSysProcAttr
+
+		haCmd.Stdout = haStdoutW
+		haCmd.Stderr = haStderrW
+
+		if launchHostAgentForeground {
+			if isRegisteredToAutoStart {
+				logrus.Warn("The instance is registered to start at login, but the --foreground option was given, so starting the instance directly")
+			}
+			haCmd.SysProcAttr = executil.ForegroundSysProcAttr
+			if err := execHostAgentForeground(limactl, haCmd); err != nil {
+				return err
+			}
+		} else if err := haCmd.Start(); err != nil {
+			return err
+		}
+	} else if err = autostart.RequestStart(ctx, inst); err != nil {
+		return fmt.Errorf("failed to request start via autostart manager: %w", err)
 	}
 
 	if err := waitHostAgentStart(ctx, haPIDPath, haStderrPath); err != nil {
@@ -259,14 +242,18 @@ func Start(ctx context.Context, inst *store.Instance, limactl string, launchHost
 
 	watchErrCh := make(chan error)
 	go func() {
-		watchErrCh <- watchHostAgentEvents(ctx, inst, haStdoutPath, haStderrPath, begin)
+		watchErrCh <- watchHostAgentEvents(ctx, inst, haStdoutPath, haStderrPath, begin, showProgress)
 		close(watchErrCh)
 	}()
 	waitErrCh := make(chan error)
-	go func() {
-		waitErrCh <- haCmd.Wait()
-		close(waitErrCh)
-	}()
+	if haCmd != nil {
+		go func() {
+			waitErrCh <- haCmd.Wait()
+			close(waitErrCh)
+		}()
+	} else {
+		defer close(waitErrCh)
+	}
 
 	select {
 	case watchErr := <-watchErrCh:
@@ -279,6 +266,10 @@ func Start(ctx context.Context, inst *store.Instance, limactl string, launchHost
 	}
 }
 
+func Start(ctx context.Context, inst *limatype.Instance, launchHostAgentForeground, showProgress bool) error {
+	return StartWithPaths(ctx, inst, launchHostAgentForeground, showProgress, "", "")
+}
+
 func waitHostAgentStart(_ context.Context, haPIDPath, haStderrPath string) error {
 	begin := time.Now()
 	deadlineDuration := 5 * time.Second
@@ -293,21 +284,41 @@ func waitHostAgentStart(_ context.Context, haPIDPath, haStderrPath string) error
 	}
 }
 
-func watchHostAgentEvents(ctx context.Context, inst *store.Instance, haStdoutPath, haStderrPath string, begin time.Time) error {
+func watchHostAgentEvents(ctx context.Context, inst *limatype.Instance, haStdoutPath, haStderrPath string, begin time.Time, showProgress bool) error {
 	ctx, cancel := context.WithTimeout(ctx, watchHostAgentTimeout(ctx))
 	defer cancel()
 
 	var (
 		printedSSHLocalPort  bool
 		receivedRunningEvent bool
+		cloudInitCompleted   bool
 		err                  error
 	)
+
 	onEvent := func(ev hostagentevents.Event) bool {
 		if !printedSSHLocalPort && ev.Status.SSHLocalPort != 0 {
 			logrus.Infof("SSH Local Port: %d", ev.Status.SSHLocalPort)
 			printedSSHLocalPort = true
+
+			// Update the instance's SSH port
+			inst.SSHLocalPort = ev.Status.SSHLocalPort
 		}
 
+		if showProgress && ev.Status.CloudInitProgress != nil {
+			progress := ev.Status.CloudInitProgress
+			if progress.Active && progress.LogLine == "" {
+				logrus.Infof("Cloud-init provisioning started...")
+			}
+
+			if progress.LogLine != "" {
+				logrus.Infof("[cloud-init] %s", progress.LogLine)
+			}
+
+			if progress.Completed {
+				cloudInitCompleted = true
+				logrus.Infof("Cloud-init progress monitoring done.")
+			}
+		}
 		if len(ev.Status.Errors) > 0 {
 			logrus.Errorf("%+v", ev.Status.Errors)
 		}
@@ -326,6 +337,11 @@ func watchHostAgentEvents(ctx context.Context, inst *store.Instance, haStdoutPat
 				err = xerr
 				return true
 			}
+
+			if showProgress && !cloudInitCompleted {
+				return false
+			}
+
 			if *inst.Config.Plain {
 				logrus.Infof("READY. Run `ssh -F %q %s` to open the shell.", inst.SSHConfigFile, inst.Hostname)
 			} else {
@@ -378,7 +394,7 @@ func LimactlShellCmd(instName string) string {
 	return shellCmd
 }
 
-func ShowMessage(inst *store.Instance) error {
+func ShowMessage(inst *limatype.Instance) error {
 	if inst.Message == "" {
 		return nil
 	}
@@ -405,7 +421,7 @@ func ShowMessage(inst *store.Instance) error {
 
 // prepareDiffDisk checks the disk size difference between inst.Disk and yaml.Disk.
 // If there is no diffDisk, return nil (the instance has not been initialized or started yet).
-func prepareDiffDisk(inst *store.Instance) error {
+func prepareDiffDisk(ctx context.Context, inst *limatype.Instance) error {
 	diffDisk := filepath.Join(inst.Dir, filenames.DiffDisk)
 
 	// Handle the instance initialization
@@ -441,9 +457,9 @@ func prepareDiffDisk(inst *store.Instance) error {
 		return errors.New("diffDisk: Shrinking is currently unavailable")
 	}
 
-	diskUtil := proxyimgutil.NewDiskUtil()
+	diskUtil := proxyimgutil.NewDiskUtil(ctx)
 
-	err = diskUtil.ResizeDisk(diffDisk, inst.Disk)
+	err = diskUtil.ResizeDisk(ctx, diffDisk, inst.Disk)
 	if err != nil {
 		return err
 	}
