@@ -4,11 +4,16 @@
 package limayaml
 
 import (
+	"bytes"
 	"encoding/json"
 	"os"
+	"path/filepath"
+	"runtime"
 	"testing"
 
 	"gotest.tools/v3/assert"
+
+	"github.com/lima-vm/lima/v2/pkg/limatype"
 )
 
 func dumpJSON(t *testing.T, d any) string {
@@ -20,7 +25,7 @@ func dumpJSON(t *testing.T, d any) string {
 const emptyYAML = "{}\n"
 
 func TestEmptyYAML(t *testing.T) {
-	var y LimaYAML
+	var y limatype.LimaYAML
 	t.Log(dumpJSON(t, y))
 	b, err := Marshal(&y, false)
 	assert.NilError(t, err)
@@ -30,14 +35,23 @@ func TestEmptyYAML(t *testing.T) {
 const defaultYAML = "{}\n"
 
 func TestDefaultYAML(t *testing.T) {
-	bytes, err := os.ReadFile("default.yaml")
+	content, err := os.ReadFile("default.yaml")
 	assert.NilError(t, err)
-	var y LimaYAML
-	err = Unmarshal(bytes, &y, "")
+	// if this is the unresolved symlink as a file, then make sure to resolve it
+	if runtime.GOOS == "windows" && bytes.HasPrefix(content, []byte{'.', '.'}) {
+		f, err := filepath.Rel(".", string(content))
+		assert.NilError(t, err)
+		content, err = os.ReadFile(f)
+		assert.NilError(t, err)
+	}
+
+	var y limatype.LimaYAML
+	err = Unmarshal(content, &y, "")
 	assert.NilError(t, err)
 	y.Images = nil                // remove default images
 	y.Mounts = nil                // remove default mounts
 	y.Base = nil                  // remove default base templates
+	y.VMOpts = nil                // remove default vmopts mapping
 	y.MinimumLimaVersion = nil    // remove minimum Lima version
 	y.MountTypesUnsupported = nil // remove default workaround for kernel 6.9-6.11
 	t.Log(dumpJSON(t, y))
