@@ -9,7 +9,7 @@ import (
 
 	"gotest.tools/v3/assert"
 
-	"github.com/lima-vm/lima/pkg/networks"
+	"github.com/lima-vm/lima/v2/pkg/networks"
 )
 
 func TestUsernetConfig(t *testing.T) {
